@@ -151,7 +151,7 @@ def upload_resources(src_dir, project=None, folder='/'):
             subprocess.check_call(['tar', '-C', resources_dir, '-czf', tar_fh.name, '.'])
             if 'folder' in applet_spec:
                 try:
-                    dxpy.DXProject(dest_project).new_folder(applet_spec['folder'], parents=True)
+                    dxpy.get_handler(dest_project).new_folder(applet_spec['folder'], parents=True)
                 except dxpy.exceptions.DXAPIError:
                     pass # TODO: make this better
             target_folder = applet_spec['folder'] if 'folder' in applet_spec else folder
@@ -235,7 +235,7 @@ def upload_applet(src_dir, uploaded_resources, check_name_collisions=True, overw
                 # TODO: test me
                 dxpy.DXProject(dest_project).remove_objects([result['id']])
             elif archive:
-                logger.info("Archiving applet %s" % (result['id']))
+                logger.debug("Archiving applet %s" % (result['id']))
                 proj = dxpy.DXProject(dest_project)
                 archive_folder = '/.Applet_archive'
                 try:
@@ -244,10 +244,11 @@ def upload_applet(src_dir, uploaded_resources, check_name_collisions=True, overw
                     proj.new_folder(archive_folder)
 
                 proj.move(objects=[result['id']], destination=archive_folder)
-                archived_applet = dxpy.DXApplet(result['id'])
+                archived_applet = dxpy.DXApplet(result['id'], project=dest_project)
                 now = datetime.datetime.fromtimestamp(archived_applet.created/1000).ctime()
                 new_name = archived_applet.name + " ({d})".format(d=now)
                 archived_applet.rename(new_name)
+                logger.info("Archived applet %s to %s:\"%s/%s\"" % (result['id'], dest_project, archive_folder, new_name))
             else:
                 raise AppBuilderException("An applet already exists at %s (id %s) and the --overwrite (-f) or --archive (-a) options were not given" % (destination_path, result['id']))
 
